Simple Django based billing application
=======================================

This project is currently work in progress and has a long way to go until
it is feature complete. Feel free to look at the source code nonetheless
and use it if you find it useful.
